@@ -3,7 +3,11 @@ Provide implementation of command-line interface's entrypoint.
 """
 import click
 
-from project_version.commands import check
+from project_version.commands import (
+    bump,
+    check,
+    release,
+)
 
 
 @click.group()
@@ -16,7 +20,9 @@ def cli() -> None:
     pass
 
 
+cli.add_command(bump)
 cli.add_command(check)
+cli.add_command(release)
 
 if __name__ == '__main__':
     cli()
