@@ -4,6 +4,8 @@ Provide help message for command line interface commands.
 PROVIDER_NAME_HELP = 'A provider of hosting for software development and version control name.'
 ORGANIZATION_NAME_HELP = "The provider's organization name."
 REPOSITORY_NAME_HELP = "The provider's repository name."
+BRANCH = 'A branch.'
 BASE_BRANCH = 'A branch to compare a project version with. Usually, a default branch.'
 HEAD_BRANCH = 'A branch to get its project version for comparison. Usually, a feature branch.'
 ACCESS_TOKEN = "The provider's API access token."
+PROJECT_VERSION = 'A project version.'
